
2023 MAR 10

*   Document version format.
*   Automate release publishing.

Snapshot of features until `v0.0.0.dev27`:

*   Initial `Alt+Shift+Q` implementation (see FS_02_25_41_81 `func_id_query_enum_items`).
*   Initial "look and feel" for user interrogation via `Tab`-auto-completion:
    *   suggest remaining args only
    *   assign arg val to the first matching arg type
    *   auto-assign implicit values for singled out `data_envelope`
*   Initial automated installation (for Python packages and Bash config).
*   Initial framework for plugin hooks:
    *   FS_78_91_27_22 `interp_control`
    *   FS_46_96_59_05 `init_control`
    *   FS_31_70_49_15 `search_control`
    *   FS_72_40_53_00 `fill_control` (dynamic defaults)
    *   FS_98_55_40_77 `invoke_control`
*   Initial FS_71_87_33_52 `help` function.
*   Initial FS_88_66_66_73 `intercept` function.
*   Initial FS_39_58_01_91 LRU query cache with TTL.
*   Propose completion for FS_01_89_09_24 interp tree (from FS_42_76_93_51 the very first zero arg).
*   FS_18_64_57_18 vararg-like func with multiple envelopes.
*   Initial FS_67_16_61_97 Git plugins.
*   Initial pre-defined test data sets:
    *   TD_63_37_05_36 demo for functional testing
    *   TD_38_03_48_51 large generated for perf testing
*   Initial `EnvMockBuilder` for consolidated mocking (see FS_66_17_43_42 test infra for details).

